==> oddmuse-1.464.tar.gz: oddmuse-1.464/hebrew-utf8.pl <==
# UTF-8 encoded Hebrew language file for use with Oddmuse
#
# Copyright (c) 2003  Erez Zukerman, IDP, ezuk at idp dot co dot il
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s
לא ניתן ליצור את %s
Invalid UserName %s: not saved.
שם משתמש שגוי: %s לא נשמר.
UserName must be 50 characters or less: not saved
שם המשתמש חייב להיות באורך 50 תווים או פחות: לא נשמר
XML::RSS is not available on this system.

diff

history
היסטוריה
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

 . . . . 

Click to edit this page

Invalid action parameter %s
פרמטר שגוי לפעולה: %s
Invalid URL.
כתובת שגויה.
Page name is missing

Page name is too long: %s
שם הדף ארוך מדי: %s
Invalid Page %s
דף לא חוקי %s
Invalid Page %s (must not end with .db)
דף לא חוקי %s (אסור שיסתיים בסיומת .db)
Invalid Page %s (must not end with .lck)
דף לא חוקי %s (אסור שיסתיים בסיומת .lck)
Page name may not contain space characters: %s
שם הדף אינו יכול להכיל תווי רווח: %s
Preview:
תצוגה מקדימה:
Preview only, not yet saved
תצוגה מקדימה בלבד, הדף עדיין לא נשמר.
Please go on to %s.
בבקשה המשך ל-%s.
Could not open %s log file
לא ניתן לפתוח את קובץ היומן %s
Error was
השגיאה היתה
Note: This error is normal if no changes have been made.
הערה: שגיאה זו היא רגילה אם לא בוצעו שינויים.
Could not open old %s log file
לא ניתן לפתוח את קובץ היומן הישן %s
No updates since %s
אין עדכונים מאז %s
Updates since %s
עדכונים מאז %s
Updates in the last %s days
עדכונים ב%s הימים האחרונים
Updates in the last %s day
עדכונים ביום האחרון
for %s only
עבור %s בלבד
List latest change per page only

List all changes

List only major changes

Include minor changes

%s days
%s ימים
List later changes

Filters

Username:
שם משתמש:
Host:

Language:

Go!
חפש!
(minor)
(קטן)
rollback

new

from %s
מ %s
History of %s
היסטוריה של %s
Compare
השוואה
Revision %s
עדכון %s
by
על-ידי
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

[Home]
[דף בית]
redirected from %s
הוכוון מחדש מ %s
Click to search for references to this page

Cookie: 

Warning
אזהרה
Database is stored in temporary directory %s
מסד הנתונים מאוחסן בספריה זמנית %s
%s seconds
%s שניות
The same page on other sites:

EditNearLinks

Last edited
עריכה אחרונה
Edited
נערך
by %s

(diff)
(הבדלים)
Run maintenance

Unlock site

Lock site

Unlock page

Lock page

Comments on this page
הערות בדף זה
Edit revision %s of this page
ערוך את גירסה %s של דף זה
Edit text of this page
ערוך את הטקסט של דף זה.
e

This page is read-only
דף זה מיועד לקריאה בלבד
View other revisions
הצג גרסאות אחרות
View current revision
הצג את הגירסה העדכנית
View all changes

Back to %s

new comment
הערה חדשה
s

Save
שמור
Preview
תצוגה מקדימה
Search:
חיפוש:
Replace:
החלפה:
Validate HTML
אמת HTML
Validate CSS
אמת CSS
Difference (from revision %1 to %2)

revision %s
עדכון %s
current revision
גירסה נוכחית
Difference (from prior %s revision)
הבדל (מגירסה %s הקודמת(
major
גדול
minor
קטן
No diff available.
לא ניתן להשיג הבדלים
Changed:
שונה:
Removed:
הוסר:
Added:
התווסף:
to
אל
Revision %s not available
גירסה %s אינה זמינה.
showing current revision instead
מציג את הגירסה הנוכחית במקומה.
Showing revision %s
מציג את גירסה %s
Cannot save an nameless page.

Cannot open %s

Cannot write %s

Could not get %s lock

Unlocking
משחרר נעילה
This operation may take several seconds...
פעולה זו עשויה להימשך מספר שניות...
Forced unlock of %s lock.
שוחררה נעילה של %s.
No unlock required.
אין צורך לשחרר נעילה.
%s hours ago
לפני %s שעות.
1 hour ago
לפני שעה
%s minutes ago
לפני %s דקות
1 minute ago
לפני דקה
%s seconds ago
לפני %s שניות
1 second ago
לפני שניה
just now
ממש עכשיו
Editing Denied
עריכה נמנעה
Editing not allowed: user, ip, or network is blocked.
עריכה אסורה: משתמש, כתובת או רשת חסומים
Contact the wiki administrator for more information.
צור קשר עם מנהל המערכת למידע נוסף
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
לא ניתן לערוך: %s מיועד לקריאה בלבד.
Only administrators can upload files.

Editing revision %s of
עורך את גירסה %s של
Editing %s
עורך את %s
Editing old revision %s.
עורך גירסה ישנה %s.
Saving this page will replace the latest revision with this text.
שמירת דף זה תחליף את הגירסה החדשה ביותר בטקסט זה.
Summary:
תקציר:
This change is a minor edit.
השינוי שאני מבצע הוא קטן.
Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Password
ססמה
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
הססמה שלך נשמרת כ-cookie, אם cookies מופעלות. Cookies עלולות ללכת לאיבוד אם תתחבר ממחשב אחר או מתוכנה אחרת.
You are currently an administrator on this site.
אתה כרגע מנהל באתר זה.
You are currently an editor on this site.
אתה כרגע עורך באתר זה.
You are a normal user on this site.
אתה משתמש רגיל באתר זה.
Your password does not match any of the  administrator or editor passwords.
הססמה שלך לא מתאימה ללסמאות של המנהל או העורך.
Password:
ססמה:
This site does not use admin or editor passwords.
אתר זה לא משתמש בססמאות מנהל ועורך.
This operation is restricted to site editors only...
פעולה זו מוגבלת לעורכים בלבד...
This operation is restricted to administrators only...
פעולה זו מוגבלת למנהלים בלבד...
Rule "%1" matched "%2" on this page.

Index of all pages
תוכן כל הדפים:
all pages

permanent anchors

near links

(for %s)

%s pages found.

Replaced: %s
הוחלף: %s
Search for: %s
חיפוש של: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
עדכון אחרון
Complete Content
תוכן מלא
The main page is %s.
הדף הראשי הוא %s.
Editing not allowed for %s.
לא ניתן לערוך את %s.
SampleUndefinedPage

%s cannot be defined.
לא ניתן להגדיר את %s
Sample_Undefined_Page
דף_לא_מוגדר_לדוגמא
[[%s]] cannot be defined.
לא ניתן להגדיר את [[%s]]
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
אנונימי
Could not get a lock to merge!
לא ניתן לגרום לנעילה להתמזג!
you

ancestor

other

Maintenance on all pages
תחזוקה לכל הדפים.
Maintenance not done.
תחזוקה לא בוצעה.
(Maintenance can only be done once every 12 hours.)
(ניתן לבצע תחזוקה רק מדי 12 שעות.)
Remove the "maintain" file or wait.
הסר את הקובץ "maintain" או המתן.
Main lock obtained.
נעילה ראשית הושגה.
Expiring keep files and deleting pages marked for deletion
מוציא קבצי שמירה מתוקפם, ומוחק דפים שסומנו למחיקה
not deleted: 

deleted
נמחק
Moving part of the %s log file.
מזיז חלק מקובץ היומן %s.
Moving %s log entries.
מזיז %s ערכי יומן.
Getting page index file for %s.

Main lock released.
נעילה ראשית שוחררה.
Set or Remove global edit lock
קבע או הסר נעילת עריכה גלובלית
Edit lock created.
נעילת עריכה נוצרה.
Edit lock removed.
נעילת עריכה הוסרה.
Set or Remove page edit lock
הגדר או הסר נעילת עריכה לדף.
Missing page id to lock/unlock...
אין מזהה דף כדי לנעול או לשחרר. (page id)
Lock for %s created.
%s ננעל.
Lock for %s removed.
נעילה הוסרה מ-%s.
Displaying Wiki Version
מציג את גירסת ה-Wiki.
Inter links:

Near links:

Too many connections by %s
יותר מדי חיבורים מ-%s.
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

Recent Visitors
מבקרים מהזמן האחרון
Referrers
מפנים
All Referrers
כל המפנים
anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Delete page

Rename this page to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Footnotes:

image: %s

Index

Languages:

Show!

Define

Full Link List
רשימת קישורים מלאה
Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

Static Copy

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
חלופי
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
חיפוש
Blog

END_OF_TRANSLATION

==> oddmuse-1.524.tar.gz: oddmuse-1.524/hebrew-utf8.pl <==
# UTF-8 encoded Hebrew language file for use with Oddmuse
#
# Copyright (c) 2003  Erez Zukerman, IDP, ezuk at idp dot co dot il
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: hebrew-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s
לא ניתן ליצור את %s
Invalid UserName %s: not saved.
שם משתמש שגוי: %s לא נשמר.
UserName must be 50 characters or less: not saved
שם המשתמש חייב להיות באורך 50 תווים או פחות: לא נשמר
This page contains an uploaded file:

XML::RSS is not available on this system.

diff

history
היסטוריה
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

Invalid action parameter %s
פרמטר שגוי לפעולה: %s
Invalid URL.
כתובת שגויה.
Page name is missing

Page name is too long: %s
שם הדף ארוך מדי: %s
Invalid Page %s
דף לא חוקי %s
Invalid Page %s (must not end with .db)
דף לא חוקי %s (אסור שיסתיים בסיומת .db)
Invalid Page %s (must not end with .lck)
דף לא חוקי %s (אסור שיסתיים בסיומת .lck)
Page name may not contain space characters: %s
שם הדף אינו יכול להכיל תווי רווח: %s
Preview:
תצוגה מקדימה:
Preview only, not yet saved
תצוגה מקדימה בלבד, הדף עדיין לא נשמר.
Please go on to %s.
בבקשה המשך ל-%s.
Could not open %s log file
לא ניתן לפתוח את קובץ היומן %s
Error was
השגיאה היתה
Note: This error is normal if no changes have been made.
הערה: שגיאה זו היא רגילה אם לא בוצעו שינויים.
Could not open old %s log file
לא ניתן לפתוח את קובץ היומן הישן %s
No updates since %s
אין עדכונים מאז %s
Updates since %s
עדכונים מאז %s
Updates in the last %s days
עדכונים ב%s הימים האחרונים
Updates in the last %s day
עדכונים ביום האחרון
for %s only
עבור %s בלבד
List latest change per page only

List all changes

List only major changes

Include minor changes

%s days
%s ימים
List later changes

Filters

Username:
שם משתמש:
Host:

Language:

Go!
חפש!
(minor)
(קטן)
rollback

new

from %s
מ %s
History of %s
היסטוריה של %s
Compare
השוואה
Revision %s
עדכון %s
by
על-ידי
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
תוכן כל הדפים:
Wiki Version
מציג את גירסת ה-Wiki.
Unlock Wiki
משחרר נעילה
Recent Visitors
מבקרים מהזמן האחרון
Password
ססמה
Run maintenance

Unlock site

Lock site

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[דף בית]
redirected from %s
הוכוון מחדש מ %s
Click to search for references to this page

Cookie: 

Warning
אזהרה
Database is stored in temporary directory %s
מסד הנתונים מאוחסן בספריה זמנית %s
%s seconds
%s שניות
The same page on other sites:

EditNearLinks

Last edited
עריכה אחרונה
Edited
נערך
by %s

(diff)
(הבדלים)
Edit revision %s of this page
ערוך את גירסה %s של דף זה
Edit this page
ערוך את הטקסט של דף זה.
e

This page is read-only
דף זה מיועד לקריאה בלבד
View other revisions
הצג גרסאות אחרות
View current revision
הצג את הגירסה העדכנית
View all changes

new comment
הערה חדשה
Homepage URL:

s

Save
שמור
Preview
תצוגה מקדימה
Search:
חיפוש:
f

Replace:
החלפה:
Validate HTML
אמת HTML
Validate CSS
אמת CSS
Difference (from revision %1 to %2)

revision %s
עדכון %s
current revision
גירסה נוכחית
Difference (from prior %s revision)
הבדל (מגירסה %s הקודמת(
major
גדול
minor
קטן
No diff available.
לא ניתן להשיג הבדלים
Old revision:

Changed:
שונה:
Removed:
הוסר:
Added:
התווסף:
to
אל
Revision %s not available
גירסה %s אינה זמינה.
showing current revision instead
מציג את הגירסה הנוכחית במקומה.
Showing revision %s
מציג את גירסה %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Could not get %s lock

This operation may take several seconds...
פעולה זו עשויה להימשך מספר שניות...
Forced unlock of %s lock.
שוחררה נעילה של %s.
No unlock required.
אין צורך לשחרר נעילה.
%s hours ago
לפני %s שעות.
1 hour ago
לפני שעה
%s minutes ago
לפני %s דקות
1 minute ago
לפני דקה
%s seconds ago
לפני %s שניות
1 second ago
לפני שניה
just now
ממש עכשיו
Editing Denied
עריכה נמנעה
Editing not allowed: user, ip, or network is blocked.
עריכה אסורה: משתמש, כתובת או רשת חסומים
Contact the wiki administrator for more information.
צור קשר עם מנהל המערכת למידע נוסף
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
לא ניתן לערוך: %s מיועד לקריאה בלבד.
Only administrators can upload files.

Editing revision %s of
עורך את גירסה %s של
Editing %s
עורך את %s
Editing old revision %s.
עורך גירסה ישנה %s.
Saving this page will replace the latest revision with this text.
שמירת דף זה תחליף את הגירסה החדשה ביותר בטקסט זה.
Summary:
תקציר:
This change is a minor edit.
השינוי שאני מבצע הוא קטן.
Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
הססמה שלך נשמרת כ-cookie, אם cookies מופעלות. Cookies עלולות ללכת לאיבוד אם תתחבר ממחשב אחר או מתוכנה אחרת.
You are currently an administrator on this site.
אתה כרגע מנהל באתר זה.
You are currently an editor on this site.
אתה כרגע עורך באתר זה.
You are a normal user on this site.
אתה משתמש רגיל באתר זה.
Your password does not match any of the  administrator or editor passwords.
הססמה שלך לא מתאימה ללסמאות של המנהל או העורך.
Password:
ססמה:
This site does not use admin or editor passwords.
אתר זה לא משתמש בססמאות מנהל ועורך.
This operation is restricted to site editors only...
פעולה זו מוגבלת לעורכים בלבד...
This operation is restricted to administrators only...
פעולה זו מוגבלת למנהלים בלבד...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

%s pages found.

Replaced: %s
הוחלף: %s
Search for: %s
חיפוש של: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
עדכון אחרון
Complete Content
תוכן מלא
The main page is %s.
הדף הראשי הוא %s.
Comments on this page
הערות בדף זה
Editing not allowed for %s.
לא ניתן לערוך את %s.
SampleUndefinedPage

%s cannot be defined.
לא ניתן להגדיר את %s
Sample_Undefined_Page
דף_לא_מוגדר_לדוגמא
[[%s]] cannot be defined.
לא ניתן להגדיר את [[%s]]
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
אנונימי
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
לא ניתן לגרום לנעילה להתמזג!
you

ancestor

other

Run Maintenance

Maintenance not done.
תחזוקה לא בוצעה.
(Maintenance can only be done once every 12 hours.)
(ניתן לבצע תחזוקה רק מדי 12 שעות.)
Remove the "maintain" file or wait.
הסר את הקובץ "maintain" או המתן.
Main lock obtained.
נעילה ראשית הושגה.
Expiring keep files and deleting pages marked for deletion
מוציא קבצי שמירה מתוקפם, ומוחק דפים שסומנו למחיקה
not deleted: 

deleted
נמחק
Moving part of the %s log file.
מזיז חלק מקובץ היומן %s.
Moving %s log entries.
מזיז %s ערכי יומן.
Getting page index file for %s.

Main lock released.
נעילה ראשית שוחררה.
Set or Remove global edit lock
קבע או הסר נעילת עריכה גלובלית
Edit lock created.
נעילת עריכה נוצרה.
Edit lock removed.
נעילת עריכה הוסרה.
Set or Remove page edit lock
הגדר או הסר נעילת עריכה לדף.
Missing page id to lock/unlock...
אין מזהה דף כדי לנעול או לשחרר. (page id)
Lock for %s created.
%s ננעל.
Lock for %s removed.
נעילה הוסרה מ-%s.
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
יותר מדי חיבורים מ-%s.
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Footnotes:

Could not find %1.html template in %2

image: %s

Index

Languages:

Show!

Define

Full Link List
רשימת קישורים מלאה
Template without parameters

The template %s is either empty or does not exist.

%s returned no data.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers
כל המפנים
Referrers
מפנים
Updating %s

Search term missing.

Static Copy

Back to %s

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
חלופי
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
חיפוש
Blog

END_OF_TRANSLATION
